pub struct Searcher { /* private fields */ }Expand description
The main entry point to the index and database.
Implementations
Sourceimpl Searcher
impl Searcher
Sourcepub fn search(&self, term: &str, config: &SearchConfig) -> Result<SearchBatch>
pub fn search(&self, term: &str, config: &SearchConfig) -> Result<SearchBatch>
Search the index and return events matching a search term.
Arguments
term- The search term that should be used to search the index.config- A SearchConfig that will modify what the search result should contain.
Returns a tuple of the count of matching documents and a list of
SearchResult.