pub struct Connection { /* private fields */ }Expand description
A Seshat database connection that can be used for reading.
Implementations
Sourceimpl Connection
impl Connection
Sourcepub fn load_checkpoints(&self) -> Result<Vec<CrawlerCheckpoint>>
pub fn load_checkpoints(&self) -> Result<Vec<CrawlerCheckpoint>>
Load all the previously stored crawler checkpoints from the database.
Arguments
Sourcepub fn is_empty(&self) -> Result<bool>
pub fn is_empty(&self) -> Result<bool>
Is the database empty. Returns true if the database is empty, false otherwise.
Sourcepub fn is_room_indexed(&self, room_id: &str) -> Result<bool>
pub fn is_room_indexed(&self, room_id: &str) -> Result<bool>
Is a room already indexed.
Returns true if the database contains events from a room, false otherwise.
Sourcepub fn get_stats(&self) -> Result<DatabaseStats>
pub fn get_stats(&self) -> Result<DatabaseStats>
Get statistical information of the database.
Sourcepub fn load_file_events(
&self,
load_config: &LoadConfig,
) -> Result<Vec<(String, Profile)>>
pub fn load_file_events( &self, load_config: &LoadConfig, ) -> Result<Vec<(String, Profile)>>
Load events that contain an mxc URL to a file.
Arguments
load_config- Configuration deciding which events and how many of them should be loaded.
Examples
let config = LoadConfig::new("!testroom:localhost").limit(10);
let result = connection.load_file_events(&config);Returns a list of tuples containing the serialized events and the profile of the sender at the time when the event was sent.
Sourcepub fn get_user_version(&self) -> Result<i64>
pub fn get_user_version(&self) -> Result<i64>
Get the user version stored in the database.
This version isn’t used anywhere internally and can be set by the user to signal changes between the JSON that gets stored inside of Seshat.